@@ -253,10 +253,16 @@ class ManagementAPIClient:
     def save_survey_to_study(self, study_key, survey_object):
         if self.auth_header is None:
             raise ValueError('need to login first')
+
+        upload_obj = {
+            "studyKey": study_key,
+            "survey": survey_object
+        }
         r = requests.post(self.management_api_url + '/v1/study/' + study_key +
-                          '/surveys', headers=self.auth_header, data=json.dumps(survey_object))
+                          '/surveys', headers=self.auth_header, data=json.dumps(upload_obj))
         if r.status_code != 200:
             raise ValueError(r.content)
+        return r.json()
         print('survey saved succcessfully')
 
     def get_surveys_in_study(self, study_key, extract_infos=False):
@@ -271,15 +277,17 @@ class ManagementAPIClient:
             return data['infos']
         return data
 
-
     def get_survey_definition(self, study_key, survey_key, version_id=''):
+        """
+            Load a Survey definition 
+            If version_id is empty load the last published version (currents)
+        """
         if self.auth_header is None:
             raise ValueError('need to login first')
-        if self.auth_header is None:
-            raise ValueError('need to login first')
-        r = requests.get(
-            self.management_api_url + '/v1/study/' + study_key + '/survey/' + survey_key + '/' + version_id,
-            headers={'Authorization': 'Bearer ' + self.token})
+        url = self.management_api_url + '/v1/study/' + study_key + '/survey/' + survey_key 
+        if version_id != "":
+            url += '/' + version_id
+        r = requests.get(url, headers={'Authorization': 'Bearer ' + self.token})
         if r.status_code != 200:
             if json.loads(r.content.decode())["error"] == "mongo: no documents in result":
                 print('Survey key does not exist in this study yet.')
@@ -289,8 +297,6 @@ class ManagementAPIClient:
         return r.json()
 
     def get_survey_keys(self, study_key):
-        if self.auth_header is None:
-            raise ValueError('need to login first')
         if self.auth_header is None:
             raise ValueError('need to login first')
         r = requests.get(
@@ -305,8 +311,6 @@ class ManagementAPIClient:
         return r.json()
 
     def get_survey_history(self, study_key, survey_key):
-        if self.auth_header is None:
-            raise ValueError('need to login first')
         if self.auth_header is None:
             raise ValueError('need to login first')
         url = '{}/v1/study/{}/survey/{}/versions'.format(self.management_api_url, study_key, survey_key)
@@ -520,6 +524,7 @@ class ManagementAPIClient:
         if r.status_code != 200:
             print(r.content)
             return None
+        r.encoding = 'utf-8'
         return r.text
 
     def get_survey_info_preview_csv(self,
@@ -673,3 +678,4 @@ class ManagementAPIClient:
         if r.status_code != 200:
             raise ValueError(r.json())
         print('user created for ' + user_object['accountId'])
+        return r.json()
